@@ -25,6 +25,7 @@ use elfo_core::{
 use elfo_macros::{message, msg_raw as msg};
 
 const MAX_WAIT_TIME: Duration = Duration::from_millis(150);
+const SYNC_YIELD_COUNT: usize = 32;
 
 pub struct Proxy {
     context: Context,
@@ -34,7 +35,7 @@ pub struct Proxy {
 
 // TODO: add `#[track_caller]` after https://github.com/rust-lang/rust/issues/78840.
 impl Proxy {
-    pub fn addr(self) -> Addr {
+    pub fn addr(&self) -> Addr {
         self.context.addr()
     }
 
@@ -97,6 +98,16 @@ impl Proxy {
         })
     }
 
+    /// Waits until the testable actor handles all previously sent messages.
+    ///
+    /// Now it's implemented as multiple calls `yield_now()`,
+    /// but the implementation can be changed in the future.
+    pub async fn sync(&mut self) {
+        for _ in 0..SYNC_YIELD_COUNT {
+            task::yield_now().await;
+        }
+    }
+
     #[deprecated]
     pub fn set_addr(&mut self, addr: Addr) {
         // This trace id will be replaced anyway.
@@ -143,7 +154,7 @@ impl Drop for Proxy {
             tls::sync_scope(self.meta.clone(), trace_id::generate(), || {
                 if let Some(envelope) = self.try_recv() {
                     panic!(
-                        "test ended, but not all messages has been consumed: {:?}",
+                        "test ended, but not all messages have been consumed: {:?}",
                         envelope
                     );
                 }
